Sagemaker local
===============

`Documentation <https://tetml.no/sagemaker-local>`_

Thin wrapper to Sagemaker local.

This repo does not include the code to execute Sagemaker Local. Instead it provides the
``sm`` command line interface that activates the code bundled together with `Common
Terraform <https://tetml.no/terraform>`_.

This repository handles dependencies to that code, the CLI wrapper and documentation.
